     {% load i18n%}
<div class="row">
  <center><h1>{{titulu}} </h1></center>
  <hr>

    {% for xxx in produtu %}





                    <div class="col-md-3" style='
                     box-shadow: 2px 2px 10px #dddddd;
                      margin:7px;'>
                               <div class="service-widget">
                                <br>
                                          
                                <h4>  <center><b> {{xxx.titulu}} </b></center></h4>
                              

                                <a href='#' data-toggle='modal' data-id="{{xxx.produtu.id}}" id='butaun_modal_detallu'  data-target= '#modal_detallu' >
                                <div class="post-media " style="visibility: visible;">
                                    <img src="{{xxx.produtu.imagen_main.url}}" style="width:100%; height: 200px;  object-fit: cover;" alt="" class="img-responsive img-rounded">
                                </div>
                                <div class="service-dit">
                                  <center>
                                  
                                <h2> <b>    $ {{xxx.produtu.presu}} </b></h2>
                              
                              </a>

                           
  
                            </center>
                              </div>
                         </div>
                     </div>
  
      {% endfor %}
      


  
  
    
                 
                </div>


        