
	{% extends 'baze.html' %}
  {% load i18n%}
    {% block content %}

    
    <div id="services" class="parallax section lb">
      <div class="container">
 
          <!-- <div class="owl-services owl-carousel owl-theme"> -->

              <div class="row">
          <div class="col-md-9 col-sm-9">



            {% for dados in info %}

              <div class="service-widget">
                <br>
               <center><font size="7" color="black" style=" line-height: 50px;"><b>{{dados.titulu}} </b></font></center> <br>
                  <div class="post-media">
                         <center>
                    <img src="{{dados.informasaun.imagen_main.url}}"  style="width: 90%; height: 400px; object-fit: cover;" alt="" class="img-responsive img-rounded">
                  </center> 
                  </div>
                  <div class="service-dit">
             
                      <p><center><i>{{dados.data}}</i> </center> {{dados.konteudu|safe}}</p>





                    
                     
                   <hr>

                    <div class="owl-services owl-carousel owl-theme owl-loaded owl-drag">
                    <div class="owl-stage-outer">
                    <div class="owl-stage" style="transform: translate3d(0px, 0px, 0px); transition: all 0s ease 0s; width: 1071px;">
                      

                     {% for dados in imagen %}
                      <div class="col-md-3 col-sm-9">
                      <div class="owl-item active" style="width: 326.667px; margin-right: 30px;"><div class="service-widget">
                            <div class="post-media wow fadeIn" style="visibility: visible; animation-name: fadeIn;">
                                <a href="{{dados.imagen.url}}" data-rel="prettyPhoto[gal]" class="hoverbutton global-radius"><i class="flaticon-unlink"></i></a>
                                <img src="{{dados.imagen.url}}" style='width: 100%; height: 200px; object-fit: cover;' alt="" class="img-responsive img-rounded">
                            </div>
   
                        </div></div>
                      </div>
                      {% endfor %}



                      
                        
                     </div>
                      </div>
                  
                      </div>
                  



















                      <hr>
                      <center>{% trans "InformasaunShare" %}  </center>
                    <hr>
                    
                    
                    <script src="https://apps.elfsight.com/p/platform.js" defer></script>
                    <div class="elfsight-app-abec5393-604f-457d-a706-bc7896e0c162"></div>
                    
                    
                      <hr>






                  </div>
              </div>
              {% endfor %}




              <!-- end service -->
          </div>

          


          
 
          {% for dados in informasaunseluk %}
              <div class="col-md-3 col-sm-3" style = "padding: 10px; ">


              <div class="service-widget">
                  <div class="post-media">
                     
                      <img src="{{dados.informasaun.imagen_main.url}}" alt="" style="width: 100%; height: 150px;"  class="img-responsive img-rounded">
                  </div>
                  <div class="service-dit">
                    <center>
                      <a href="{% url 'vizitor:detalluinformasaun' dados.informasaun.id %}"><h4>{{dados.titulu}} . <br>  {{dados.data}}</h4></a> <br>
                   
                     
                    </center>
            
   
                  </div>
              </div>



              
              <!-- end service -->
          </div>
          {% endfor %}



          
              
   </div>
  </div>
         
{% endblock content %}